import { Store } from 'redux';
export interface Storage {
    get(key: string): string | null;
    set(key: string, data: string): void;
    remove(key: string): void;
}
export declare type Selector<SelectedState, Fullstate> = (state: Fullstate) => SelectedState;
export declare type Save<SelectedState> = (key: string, state: SelectedState) => void;
export declare type Load<SelectedState> = (key: string) => SelectedState | null;
export interface BaseOptions<FullState, SelectedState> {
    key: string;
    selector: Selector<SelectedState, FullState>;
}
export interface StorageOptions<Fullstate, SelectedState> extends BaseOptions<Fullstate, SelectedState> {
    storage: Storage;
    save?: Save<SelectedState>;
    load?: Load<SelectedState>;
}
export interface CustomOptions<Fullstate, SelectedState> extends BaseOptions<Fullstate, SelectedState> {
    save: Save<SelectedState>;
    load: Load<SelectedState>;
}
export interface Keep<FullState, SelectedState> {
    key: string;
    selector: Selector<SelectedState, FullState>;
    save: Save<SelectedState>;
    load: Load<SelectedState>;
}
export declare function keep<F, S>(options: StorageOptions<F, S> | CustomOptions<F, S>): Keep<F, S>;
export declare const HYDRATE = "keep/HYDRATE";
export default function <FullState>(...keeps: Keep<FullState, any>[]): (store: Store<FullState>) => void;
